==> grid-control-1.7.1.tar.gz: grid-control-1.7.1/packages/grid_control_gui/ansi.py <==
# | Copyright 2014-2016 Karlsruhe Institute of Technology
# |
# | Licensed under the Apache License, Version 2.0 (the "License");
# | you may not use this file except in compliance with the License.
# | You may obtain a copy of the License at
# |
# |     http://www.apache.org/licenses/LICENSE-2.0
# |
# | Unless required by applicable law or agreed to in writing, software
# | distributed under the License is distributed on an "AS IS" BASIS,
# | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# | See the License for the specific language governing permissions and
# | limitations under the License.

import sys, tty, fcntl, struct, termios
from python_compat import imap

class Console(object):
	attr = {'COLOR_BLACK': '30', 'COLOR_RED': '31', 'COLOR_GREEN': '32',
		'COLOR_YELLOW': '33', 'COLOR_BLUE': '34', 'COLOR_MAGENTA': '35',
		'COLOR_CYAN': '36', 'COLOR_WHITE': '37', 'BOLD': '1', 'RESET': '0'}
	cmd = {'savePos': '7', 'loadPos': '8', 'eraseDown': '[J', 'erase': '[2J'}
	for (name, esc) in attr.items():
		locals()[name] = esc

	def fmt(cls, data, attr = None):
		class ColorString(object):
			def __init__(self, data, attr):
				(self._data, self._attr) = (data, attr)
			def __len__(self):
				return len(self._data)
			def __str__(self):
				return '\033[%sm%s\033[0m' % (str.join(';', [Console.RESET] + self._attr), self._data)
		if sys.stdout.isatty():
			return ColorString(data, attr or [])
		return data
	fmt = classmethod(fmt)

	def __init__(self):
		(self.stdout, self.stdin) = (sys.stdout, sys.stdin)
		def callFactory(x):
			return lambda: self._esc(x)
		for (proc, esc) in Console.cmd.items():
			setattr(self, proc, callFactory(esc))

	def _esc(self, data):
		self.stdout.write('\033' + data)
		self.stdout.flush()

	def getmaxyx(self):
		winsize_ptr = fcntl.ioctl(0, termios.TIOCGWINSZ, struct.pack("HHHH", 0, 0, 0, 0))
		winsize = struct.unpack('HHHH', winsize_ptr)
		return (winsize[0], winsize[1])

	def getyx(self):
		fd = sys.stdin.fileno()
		state = termios.tcgetattr(fd)
		tty.setraw(fd)
		self._esc('[6n')
		output = ''
		while not output.endswith('R'):
			output += sys.stdin.read(1)
		termios.tcsetattr(fd, termios.TCSADRAIN, state)
		return tuple(imap(int, output[2:-1].split(';')))

	def move(self, row, col):
		self._esc('[%d;%dH' % (row, col))

	def setscrreg(self, top = 0, bottom = 0):
		self._esc('[%d;%dr' % (top, bottom))

	def addstr(self, data, attr = None):
		self.stdout.write(str(Console.fmt(data, attr)))
		self.stdout.flush()

==> grid-control-1.8.64.tar.gz: grid-control-1.8.64/packages/grid_control_gui/ansi.py <==
# | Copyright 2014-2016 Karlsruhe Institute of Technology
# |
# | Licensed under the Apache License, Version 2.0 (the "License");
# | you may not use this file except in compliance with the License.
# | You may obtain a copy of the License at
# |
# |     http://www.apache.org/licenses/LICENSE-2.0
# |
# | Unless required by applicable law or agreed to in writing, software
# | distributed under the License is distributed on an "AS IS" BASIS,
# | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# | See the License for the specific language governing permissions and
# | limitations under the License.

import re, sys, tty, fcntl, struct, termios
from python_compat import imap

class Console(object):
	attr = {'COLOR_BLACK': '30', 'COLOR_RED': '31', 'COLOR_GREEN': '32',
		'COLOR_YELLOW': '33', 'COLOR_BLUE': '34', 'COLOR_MAGENTA': '35',
		'COLOR_CYAN': '36', 'COLOR_WHITE': '37', 'BOLD': '1', 'RESET': '0'}
	cmd = {'savePos': '7', 'loadPos': '8', 'eraseDown': '[J', 'erase': '[2J'}
	for (name, esc) in attr.items():
		locals()[name] = esc

	def fmt(cls, data, attr = None):
		class ColorString(object):
			def __init__(self, data, attr):
				(self._data, self._attr) = (data, attr)
			def __len__(self):
				return len(self._data)
			def __str__(self):
				return '\033[%sm%s\033[0m' % (str.join(';', [Console.RESET] + self._attr), self._data)
		if sys.stdout.isatty():
			return ColorString(data, attr or [])
		return data
	fmt = classmethod(fmt)

	def fmt_strip(cls, value):
		return re.sub(r'\x1b(>|=|\[[^A-Za-z]*[A-Za-z])', '', value)
	fmt_strip = classmethod(fmt_strip)

	def __init__(self):
		(self.stdout, self.stdin) = (sys.stdout, sys.stdin)
		def callFactory(x):
			return lambda: self._esc(x)
		for (proc, esc) in Console.cmd.items():
			setattr(self, proc, callFactory(esc))

	def _esc(self, data):
		self.stdout.write('\033' + data)
		self.stdout.flush()

	def getmaxyx(self):
		winsize_ptr = fcntl.ioctl(0, termios.TIOCGWINSZ, struct.pack("HHHH", 0, 0, 0, 0))
		winsize = struct.unpack('HHHH', winsize_ptr)
		return (winsize[0], winsize[1])

	def getyx(self):
		fd = sys.stdin.fileno()
		state = termios.tcgetattr(fd)
		tty.setraw(fd)
		self._esc('[6n')
		output = ''
		while not output.endswith('R'):
			output += sys.stdin.read(1)
		termios.tcsetattr(fd, termios.TCSADRAIN, state)
		return tuple(imap(int, output[2:-1].split(';')))

	def move(self, row, col):
		self._esc('[%d;%dH' % (row, col))

	def setscrreg(self, top = 0, bottom = 0):
		self._esc('[%d;%dr' % (top, bottom))

	def addstr(self, data, attr = None):
		self.stdout.write(str(Console.fmt(data, attr)))
		self.stdout.flush()
